==> scanpy-1.9.0.tar.gz: scanpy-1.9.0/README.md <==
[![Stars](https://img.shields.io/github/stars/theislab/scanpy?logo=GitHub&color=yellow)](https://github.com/theislab/scanpy/stargazers)
[![PyPI](https://img.shields.io/pypi/v/scanpy?logo=PyPI)](https://pypi.org/project/scanpy)
[![PyPIDownloads](https://pepy.tech/badge/scanpy)](https://pepy.tech/project/scanpy)
[![Conda](https://img.shields.io/conda/dn/conda-forge/scanpy?logo=Anaconda)](https://anaconda.org/conda-forge/scanpy)
[![Docs](https://readthedocs.com/projects/icb-scanpy/badge/?version=latest)](https://scanpy.readthedocs.io)
[![Build Status](https://dev.azure.com/theislab/scanpy/_apis/build/status/theislab.scanpy?branchName=master)](https://dev.azure.com/theislab/scanpy/_build)
![Discourse topics](https://img.shields.io/discourse/posts?color=yellow&logo=discourse&server=https%3A%2F%2Fdiscourse.scverse.org)
[![Chat](https://img.shields.io/badge/zulip-join_chat-%2367b08f.svg)](https://scverse.zulipchat.com)

# Scanpy – Single-Cell Analysis in Python

Scanpy is a scalable toolkit for analyzing single-cell gene expression data
built jointly with [anndata](https://anndata.readthedocs.io).  It includes
preprocessing, visualization, clustering, trajectory inference and differential
expression testing.  The Python-based implementation efficiently deals with
datasets of more than one million cells.

Discuss usage on the scverse [Discourse]. Read the [documentation].
If you'd like to contribute by opening an issue or creating a pull request, please take a look at our [contributing guide].
If Scanpy is useful for your research, consider citing [Genome Biology (2018)].

[contributing guide]: CONTRIBUTING.md
[discourse]: https://discourse.scverse.org/
[documentation]: https://scanpy.readthedocs.io
[genome biology (2018)]: https://doi.org/10.1186/s13059-017-1382-0

==> scanpy-1.9.3.tar.gz: scanpy-1.9.3/README.md <==
[![Stars](https://img.shields.io/github/stars/scverse/scanpy?logo=GitHub&color=yellow)](https://github.com/scverse/scanpy/stargazers)
[![PyPI](https://img.shields.io/pypi/v/scanpy?logo=PyPI)](https://pypi.org/project/scanpy)
[![PyPIDownloads](https://pepy.tech/badge/scanpy)](https://pepy.tech/project/scanpy)
[![Conda](https://img.shields.io/conda/dn/conda-forge/scanpy?logo=Anaconda)](https://anaconda.org/conda-forge/scanpy)
[![Docs](https://readthedocs.com/projects/icb-scanpy/badge/?version=latest)](https://scanpy.readthedocs.io)
[![Build Status](https://dev.azure.com/scverse/scanpy/_apis/build/status/theislab.scanpy?branchName=master)](https://dev.azure.com/scverse/scanpy/_build)
![Discourse topics](https://img.shields.io/discourse/posts?color=yellow&logo=discourse&server=https%3A%2F%2Fdiscourse.scverse.org)
[![Chat](https://img.shields.io/badge/zulip-join_chat-%2367b08f.svg)](https://scverse.zulipchat.com)

# Scanpy – Single-Cell Analysis in Python

Scanpy is a scalable toolkit for analyzing single-cell gene expression data
built jointly with [anndata](https://anndata.readthedocs.io).  It includes
preprocessing, visualization, clustering, trajectory inference and differential
expression testing.  The Python-based implementation efficiently deals with
datasets of more than one million cells.

Discuss usage on the scverse [Discourse]. Read the [documentation].
If you'd like to contribute by opening an issue or creating a pull request, please take a look at our [contributing guide].
If Scanpy is useful for your research, consider citing [Genome Biology (2018)].

[contributing guide]: CONTRIBUTING.md
[discourse]: https://discourse.scverse.org/
[documentation]: https://scanpy.readthedocs.io
[genome biology (2018)]: https://doi.org/10.1186/s13059-017-1382-0
